@@ -351,12 +351,14 @@ sub _get_desired_caps ( $self, $args ) {
     if ( $self->{wdh}->{is_chrome} ) {
         my @headless = $args->{headless} || !$MSWIN ? ( '--headless', '--disable-gpu' ) : ();
 
+        my $ua = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/60.0.3112.101 Safari/537.36';
+
         $caps->{chromeOptions} = {
 
             # '--headless', '--disable-gpu',
             # "user-data-dir=$ENV->{TEMP_DIR}"
             # 'no-sandbox',
-            args => [ 'start-maximized', 'disable-infobars', '--disable-popup-blocking', '--disable-default-apps', '--disable-web-security', "user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str, @headless, ( $args->{args} ? $args->{args}->@* : () ), '--no-sandbox' ],
+            args => [ 'start-maximized', 'disable-infobars', '--disable-popup-blocking', '--disable-default-apps', '--disable-web-security', "user-data-dir=$ENV->{TEMP_DIR}chrome-wds-" . P->uuid->str, @headless, ( $args->{args} ? $args->{args}->@* : () ), '--no-sandbox', "--user-agent=$ua" ],
             binary => $args->{bin} // q[],
 
             #     prefs => {
